@@ -171,6 +171,23 @@ def update_job_status(job, status, attach_log=False):
         return put(job['url'], json=job)
 
 
+def update_job_next_round(job):
+    """
+    Add up plus 1 in w.r.t. the current round.
+    :param dict job: JSON-like object containing job's information.
+    :return:
+    """
+    logger.info('Updating to next round...')
+    # Avoid updating the files
+    job.pop('trained_model', None)
+    job.pop('log', None)
+
+    # Step up in the next round
+    job['current_round'] += 1
+
+    return put(job['url'], json=job)
+
+
 def upload_trained_model(job, model):
     """Upload train model to job"""
     # Remove previous logs and model files
@@ -237,18 +254,29 @@ def load_model_from_url(model_url):
     return model_zoo.load_url(model_url, progress=False)
 
 
-def load_base_model(job_url):
+def load_base_model(job):
     """
     Downloads base torch model.
-    :param str job_url: URL of the job containing the model.
-    :return str: File path to the downloaded model.
+    :param dict job: JSON-like object containing job's information.
+    :return torch.Module: torch model loaded.
     """
     logger.info('Downloading base model...')
-    json = get(job_url)  # Get job data
-    json = get(json['model'])  # Get model url
+    model_file_url = get(job['model'])['model_file']
 
     # Download file and return model file path
-    return load_model_from_url(json['model_file'])
+    return load_model_from_url(model_file_url)
+
+
+def load_trained_model(job):
+    """
+    Download trained model from job.
+    :param dict job: JSON-like object containing job's information.
+    :return torch.Module: torch model loaded.
+    """
+    logger.info('Downloading trained model...')
+    trained_model_file_url = get(job['url'])['trained_model']
+
+    return load_model_from_url(trained_model_file_url)
 
 
 def get_models():
